  // *******************************************************************************
  // *
  // *  Copyright (C) 2007 Dallas/Maxim Semiconductor Corporation. 
  // *  All rights Reserved. Printed in U.S.A.
  // *
  // *  This software is protected by copyright laws of the United States and of 
  // *  foreign countries.  This material may also be protected by patent laws of
  // *  the United States and of foreign countries. This software is furnished 
  // *  under a license agreement and/or a nondisclosure agreement and may only 
  // *  be used or copied in accordance with the terms of those agreements.  The 
  // *  mere transfer of this software does not imply any licenses of trade 
  // *  secrets, proprietary technology, copyrights, patents, trademarks, 
  // *  maskwork rights, or any other form of intellectual property whatsoever. 
  // *  Dallas/Maxim Semiconductor retains all ownership rights.
  // *
  // *
  // *     Description: MAX2990
  // *        Filename: i2c.c
  // *          Author: Konrad Scheuer
  // *        Compiler: IAR
  // *         Version: 2.20I
  // *         Created: 2009_11_27
  // *
  // *         Purpose: Basic I2C read and write routines
  // *												
  // *******************************************************************************


#include <stdio.h>
#include <stdlib.h>
#include <intrinsics.h>
#include "inc/iomaxqwv17_B1.h"
#include "global.h"
#include "i2c.h"


void i2c_init(UINT16 clk)
{
  unsigned i;
  
  PO1_bit.Bit2 = 0;  	// disables the GPIO function of the 
  PO1_bit.Bit3 = 0;  	// I2C Pins  

  I2CCN_bit.I2CEN = 0; // make sure I2C is disabled 
                       // to allow changing the I2C settings

  I2CCN_bit.I2CMST = 1; 	  // set the I2C Engine to Master Mode
  I2CCN_bit.I2CEA = 0;  	  //7-bit Address mode  

  I2CCK_bit.I2CCKL = 0x40;  // 2s CLK-low, to define I2C frequency
  I2CCK_bit.I2CCKH = 0x40;  // 2s CLK-high, to define I2C frequency 

  for (i = 0; i < 0xffff; i++);
  I2CTO = 250;  // I2C_TIMEOUT allows 200 I2C bits after start otherwise 
                // Timeout will occur for, reliable communicaion check TOI bit,
                // or use the TO interrupt
  I2CST = 0x400; // reset status register
  
  I2CCN_bit.I2CEN = 1; // enable the I2C Engine
}


void i2c_init_write(void)
{
  I2CCN_bit.I2CMODE = 0; // I2C transmitt-mode
  I2CCN_bit.I2CACK = 1;  // create I2C NACK so that slave can create ACK  
  I2C_START;             // generate I2C START condition
  
  while( I2CCN_bit.I2CSTART == 1 ); // wait until the START condition (Deadly Embrace!!!)  
						            // was put to the I2C bus
  I2CST_bit.I2CSRI = 0;             // Reset the I2C Interrupt flag
}


void i2c_init_read(void)
{
  I2CCN_bit.I2CMODE = 1;  // I2C read-mode  
  I2CCN_bit.I2CACK = 0;   // create I2C ACK after receive    
  I2C_START;              // generate I2C START condition

  while( I2CCN_bit.I2CSTART == 1 ); // wait until the START condition (Deadly Embrace!!!)  
  I2CST_bit.I2CSRI = 0;             // Reset the I2C Interrupt flag 
}  

void i2c_write(UINT8 data)
{
  I2CBUF = data;                  // put the data on the I2C bus
  while( I2CST_bit.I2CTXI == 0 ); // wait for transfer complete (Deadly Embrace!!!)  
  I2CST_bit.I2CTXI = 0;           // Reset the I2C Transmitt complete 
                                  // Interrupt flag
}

void i2c_read(UINT8 *data)
{
  I2CBUF = 0xff; // put "all ones" on the I2C bus so that slave can pull
                 // the bus down to generate zeros
    
  while( !I2CST_bit.I2CRXI ); // wait for receive complete (Deadly Embrace!!!)  
  I2CST_bit.I2CRXI=0;         // Reset the I2C Receive complete 
                              // Interrupt flag
  
  *data = I2CBUF;             // write the data to the pointer
}
