/********************************************************************
 *
 * System register and bit definitions for Dallas Semiconductor/Maxim
 * MAXQ.
 *
 * This file supports assembler and C development for MAXQ
 *
 * Copyright 2004 IAR Systems. All rights reserved.
 *
 * $Revision: 1.3 $
 *
 ********************************************************************/

#ifndef __IOMAXQ
#define __IOMAXQ

#if (((__TID__ >> 8) & 0x7F) != 0x42)     /* 0x42 = 66 dec */
#error iomaxqxx.h file for use with ICCMAXQ/AMAXQ only
#endif

#ifdef __IAR_SYSTEMS_ICC__
#pragma language=extended

#include "iomacro.h"

/*-------------------------------------------------------------------------
 *   Special Function Registers
 *-------------------------------------------------------------------------*/

/*-------------------------------*
 *           Module 8            *
 *-------------------------------*/


/* Processor Status Flags register */
__no_init volatile __io union
{
  unsigned char PSF;
  struct
  {
    unsigned char E              : 1;
    unsigned char C              : 1;
    unsigned char OV             : 1;
    unsigned char GPF0           : 1;
    unsigned char GPF1           : 1;
    unsigned char                : 1;
    unsigned char S              : 1;
    unsigned char Z              : 1;
  } PSF_bit;
} @ _M(8,4);


/* Interrupt and Control register */
__no_init volatile __io union
{
  unsigned char IC;
  struct
  {
    unsigned char IGE            : 1;
    unsigned char INS            : 1;
    unsigned char                : 1;
    unsigned char                : 1;
    unsigned char                : 1;
    unsigned char CGDS           : 1;
    unsigned char                : 1;
    unsigned char                : 1;
  } IC_bit;
} @ _M(8,5);


/* Interrupt Mask Register */
__no_init volatile __io union
{
  unsigned char IMR;
  struct
  {
    unsigned char IM0           : 1;
    unsigned char IM1           : 1;
    unsigned char IM2           : 1;
    unsigned char IM3           : 1;
    unsigned char IM4           : 1;
    unsigned char IM5           : 1;
    unsigned char               : 1;
    unsigned char IMS           : 1;
  } IMR_bit;
} @ _M(8,6);


/* System Control register */
__no_init volatile __io union
{
  unsigned char SR;
  struct
  {
    unsigned char                : 1;
    unsigned char PWL            : 1;
    unsigned char ROD            : 1;
    unsigned char UPA            : 1;
    unsigned char CDA0           : 1;
    unsigned char CDA1           : 1;
    unsigned char                : 1;
    unsigned char TAP            : 1;
  } SC_bit;
} @ _M(8,8);


/* Interrupt Identification Register */
__no_init volatile __io union
{
  unsigned char IIR;
  struct
  {
    unsigned char II0           : 1;
    unsigned char II1           : 1;
    unsigned char II2           : 1;
    unsigned char II3           : 1;
    unsigned char II4           : 1;
    unsigned char II5           : 1;
    unsigned char               : 1;
    unsigned char IIS           : 1;
  } IIR_bit;
} @ _M(8,0x0B);


/* CKCN and WDCN are defined in each of the implementation specific header files */


/*-------------------------------*
 *           Module 13            *
 *-------------------------------*/

 /* Interrupt Vector register */
__no_init volatile __io unsigned char IV @ _M(0x0D,2);   /* Interrupt Vector register */


#pragma language=default
#endif /* __IAR_SYSTEMS_ICC__  */
#endif /* __IOMAXQ */
