/********************************************************************
 *
 *  Register and bit definitions for Dallas Semiconductor/Maxim
 *  MAXQWV17.
 *
 *  This file supports assembler and C development for MAXQWV17
 *
 *  Copyright 2003 IAR Systems. All rights reserved.
 *
 *  Author: Ben Smith
 *
 *  Created: 8/8/2006
 *
 *
 ********************************************************************/


#ifndef __IOMAXQWV17
#define __IOMAXQWV17

#if (((__TID__ >> 8) & 0x7F) != 0x42)     /* 0x42 = 66 dec */
#error iomaxqxx.h file for use with ICCMAXQ/AMAXQ only
#endif


#ifdef __IAR_SYSTEMS_ICC__
#pragma language=extended

#include "iomacro.h"

/*-------------------------------------------------------------------------
 *   Special Function Registers
 *-------------------------------------------------------------------------*/

/*-------------------------------*
 *           Module 0            *
 *-------------------------------*/

/* Port 0 Output Register */
__no_init volatile __io union
{
  unsigned char PO0;
  struct
  {
  unsigned char Bit0        :1;
  unsigned char Bit1        :1;
  unsigned char Bit2        :1;
  unsigned char Bit3        :1;
  unsigned char Bit4        :1;
  unsigned char Bit5        :1;
  unsigned char Bit6        :1;
  unsigned char Bit7        :1;
  } PO0_bit;
} @ _M(0,0);


/* Port 1 Output Register */
__no_init volatile __io union
{
  unsigned char PO1;
  struct
  {
  unsigned char Bit0        :1;
  unsigned char Bit1        :1;
  unsigned char Bit2        :1;
  unsigned char Bit3        :1;
  unsigned char Bit4        :1;
  unsigned char Bit5        :1;
  unsigned char Bit6        :1;
  unsigned char Bit7        :1;
  } PO1_bit;
} @ _M(0,1);


/* Port 2 Output Register */
__no_init volatile __io union
{
  unsigned char PO2;
  struct
  {
  unsigned char Bit0        :1;
  unsigned char Bit1        :1;
  unsigned char Bit2        :1;
  unsigned char Bit3        :1;
  unsigned char Bit4        :1;
  unsigned char Bit5        :1;
  unsigned char Bit6        :1;
  unsigned char Bit7        :1;
  } PO2_bit;
} @ _M(0,2);


/* Port 3 Output Register */
__no_init volatile __io union
{
  unsigned short PO3;
  struct
  {
  unsigned short Bit0        :1;
  unsigned short Bit1        :1;
  unsigned short Bit2        :1;
  unsigned short Bit3        :1;
  unsigned short Bit4        :1;
  unsigned short Bit5        :1;
  unsigned short Bit6        :1;
  unsigned short Bit7        :1;
  unsigned short Bit8        :1;
  } PO3_bit;
} @ _M(0,3);


/* External Interrupt Flag 0 Register */
__no_init volatile __io union
{
  unsigned char EIF0;
  struct
  {
    unsigned char IE0             : 1;
    unsigned char IE1             : 1;
    unsigned char IE2             : 1;
    unsigned char IE3             : 1;
    unsigned char IE4             : 1;
    unsigned char IE5             : 1;
    unsigned char IE6             : 1;
    unsigned char IE7             : 1;
  } EIF0_bit;
} @ _M(0,4);



/* External Interrupt Enable 0 Register */
__no_init volatile __io union
{
  unsigned char EIE0;
  struct
  {
    unsigned char EX0             : 1;
    unsigned char EX1             : 1;
    unsigned char EX2             : 1;
    unsigned char EX3             : 1;
    unsigned char EX4             : 1;
    unsigned char EX5             : 1;
    unsigned char EX6             : 1;
    unsigned char EX7             : 1;
  } EIE0_bit;
} @ _M(0,5);


/* Port 0 Input Register */
__no_init volatile __io union
{
  unsigned char PI0;
  struct
  {
  unsigned char Bit0        :1;
  unsigned char Bit1        :1;
  unsigned char Bit2        :1;
  unsigned char Bit3        :1;
  unsigned char Bit4        :1;
  unsigned char Bit5        :1;
  unsigned char Bit6        :1;
  unsigned char Bit7        :1;
  } PI0_bit;
} @ _M(0,0x8);


/* Port 1 Input Register */
__no_init volatile __io union
{
  unsigned char PI1;
  struct
  {
  unsigned char Bit0        :1;
  unsigned char Bit1        :1;
  unsigned char Bit2        :1;
  unsigned char Bit3        :1;
  unsigned char Bit4        :1;
  unsigned char Bit5        :1;
  unsigned char Bit6        :1;
  unsigned char Bit7        :1;
  } PI1_bit;
} @ _M(0,0x9);


/* Port 2 Input Register */
__no_init volatile __io union
{
  unsigned char PI2;
  struct
  {
  unsigned char Bit0        :1;
  unsigned char Bit1        :1;
  unsigned char Bit2        :1;
  unsigned char Bit3        :1;
  unsigned char Bit4        :1;
  unsigned char Bit5        :1;
  unsigned char Bit6        :1;
  unsigned char Bit7        :1;
  } PI2_bit;
} @ _M(0,0xA);

/* Port 3 Input Register */
__no_init volatile __io union
{
  unsigned short PI3;
  struct
  {
  unsigned short Bit0        :1;
  unsigned short Bit1        :1;
  unsigned short Bit2        :1;
  unsigned short Bit3        :1;
  unsigned short Bit4        :1;
  unsigned short Bit5        :1;
  unsigned short Bit6        :1;
  unsigned short Bit7        :1;
  unsigned short Bit8        :1;
  } PI3_bit;
} @ _M(0,0xB);


/* External Interrupt Edge Select 0 Register */
__no_init volatile __io union
{
  unsigned char EIES0;
  struct
  {
    unsigned char IT0             : 1;
    unsigned char IT1             : 1;
    unsigned char IT2             : 1;
    unsigned char IT3             : 1;
    unsigned char IT4             : 1;
    unsigned char IT5             : 1;
    unsigned char IT6             : 1;
    unsigned char IT7             : 1;
  } EIES0_bit;
} @ _M(0,0xC);

/* External GPIO Clock Control Register */
__no_init volatile __io union
{
  unsigned char EGCKCN;
  struct
  {
    unsigned char X1EGCKSEL       : 1;
    unsigned char X2EGCKSEL       : 1;
  } EGCKCN_bit;
} @ _M(0,0xD);

/* Port 0 Direction Register */
__no_init volatile __io union
{
  unsigned char PD0;
  struct
  {
  unsigned char Bit0        :1;
  unsigned char Bit1        :1;
  unsigned char Bit2        :1;
  unsigned char Bit3        :1;
  unsigned char Bit4        :1;
  unsigned char Bit5        :1;
  unsigned char Bit6        :1;
  unsigned char Bit7        :1;
  } PD0_bit;
} @ _M(0,0x10);


/* Port 1 Direction Register */
__no_init volatile __io union
{
  unsigned char PD1;
  struct
  {
  unsigned char Bit0        :1;
  unsigned char Bit1        :1;
  unsigned char Bit2        :1;
  unsigned char Bit3        :1;
  unsigned char Bit4        :1;
  unsigned char Bit5        :1;
  unsigned char Bit6        :1;
  unsigned char Bit7        :1;
  } PD1_bit;
} @ _M(0,0x11);


/* Port 2 Direction Register */
__no_init volatile __io union
{
  unsigned char PD2;
  struct
  {
  unsigned char Bit0        :1;
  unsigned char Bit1        :1;
  unsigned char Bit2        :1;
  unsigned char Bit3        :1;
  unsigned char Bit4        :1;
  unsigned char Bit5        :1;
  unsigned char Bit6        :1;
  unsigned char Bit7        :1;
  } PD2_bit;
} @ _M(0,0x12);

/* Port 3 Direction Register */
__no_init volatile __io union
{
  unsigned short PD3;
  struct
  {
  unsigned short Bit0        :1;
  unsigned short Bit1        :1;
  unsigned short Bit2        :1;
  unsigned short Bit3        :1;
  unsigned short Bit4        :1;
  unsigned short Bit5        :1;
  unsigned short Bit6        :1;
  unsigned short Bit7        :1;
  unsigned short Bit8        :1;
  } PD3_bit;
} @ _M(0,0x13);


/* RTC Trim Register */
__no_init volatile __io union
{
  unsigned char RTRM;
  struct
  {
  unsigned char TRM         :7;
  unsigned char TSGN        :1;
  } RTRM_bit;
} @ _M(0,0x18);


/* RTC Control Register */
__no_init volatile __io union
{
  unsigned short RCNT;
  struct
  {
  unsigned short RTCE       :1;
  unsigned short ADE        :1;
  unsigned short ASE        :1;
  unsigned short BUSY       :1;
  unsigned short RDY        :1;
  unsigned short RDYE       :1;
  unsigned short ALDF       :1;
  unsigned short ALSF       :1;
  unsigned short SQE        :1;
  unsigned short            :4;
  unsigned short ACS        :1;
  unsigned short X32D       :1;
  unsigned short WE         :1;
  } RCNT_bit;
} @ _M(0,0x19);


__no_init volatile __io unsigned char RTSS @ _M(1,0x1A);   /* RTC Sub-Second Counter */


__no_init volatile __io unsigned short RTSH @ _M(0,0x1B); /* RTC Seconds Counter - High */


__no_init volatile __io unsigned short RTSL @ _M(0,0x1C); /* RTC Seconds Counter - Low */


__no_init volatile __io unsigned char RSSA @ _M(1,0x1D);   /* RTC Sub-Second Alarm */


__no_init volatile __io unsigned char RASH @ _M(1,0x1E);   /* RTC Alarm - High */


__no_init volatile __io unsigned short RASL @ _M(0,0x1F); /* RTC Alarm - Low */


/*-------------------------------*
 *           Module 1            *
 *-------------------------------*/


__no_init volatile __io unsigned short SPIB @ _M(1,0); /* SPI Data Buffer Register */


/* SPI Control Register */
__no_init volatile __io union
{
  unsigned char SPICN;
  struct
  {
    unsigned char SPIEN          : 1;
    unsigned char MSTM           : 1;
    unsigned char MODFE          : 1;
    unsigned char MODF           : 1;
    unsigned char WCOL           : 1;
    unsigned char ROVR           : 1;
    unsigned char SPIC           : 1;
    unsigned char STBY           : 1;
  } SPICN_bit;
} @ _M(1,1);


/* SPI Configuration Register */
__no_init volatile __io union
{
  unsigned char SPICF;
  struct
  {
    unsigned char CKPOL          : 1;
    unsigned char CKPHA          : 1;
    unsigned char CHR            : 1;
    unsigned char                : 4;
    unsigned char ESPII          : 1;
  } SPICF_bit;
} @ _M(1,2);


__no_init volatile __io unsigned char SPICK @ _M(1,3);   /* SPI Clock Register */


__no_init volatile __io unsigned short I2CBUF @ _M(1,4); /* I2C Data Buffer Register */


/* I2C Status Register */
__no_init volatile __io union
{
  unsigned short I2CST;
  struct
  {
  unsigned short I2CSRI     :1;
  unsigned short I2CTXI     :1;
  unsigned short I2CRXI     :1;
  unsigned short I2CSTRI    :1;
  unsigned short I2CTOI     :1;
  unsigned short I2CAMI     :1;
  unsigned short I2CALI     :1;
  unsigned short I2CNACKI   :1;
  unsigned short I2CGCI     :1;
  unsigned short I2CROI     :1;
  unsigned short I2CSCL     :1;
  unsigned short            :3;
  unsigned short I2CBUSY    :1;
  unsigned short I2CBUS     :1;
  } I2CST_bit;
} @ _M(1,5);


/* I2C Interrupt Enable Register */
__no_init volatile __io union
{
  unsigned short I2CIE;
  struct
  {
  unsigned short I2CSRIE    :1;
  unsigned short I2CTXIE    :1;
  unsigned short I2CRXIE    :1;
  unsigned short I2CSTRIE   :1;
  unsigned short I2CTOIE    :1;
  unsigned short I2CAMIE    :1;
  unsigned short I2CALIE    :1;
  unsigned short I2CNACKIE  :1;
  unsigned short I2CGCIE    :1;
  unsigned short I2CROIE    :1;
  unsigned short I2CSTREN   :1;
  } I2CIE_bit;
} @ _M(1,6);

/* Software breakpoint register */
__no_init volatile __io union
{
  unsigned char BRKP;
  struct
  {
    unsigned char BREAK     : 1;
    unsigned char BPT       : 6;
  } BRKP_bit;
} @ _M(1,7);


/* Power Management Register */
__no_init volatile __io union
{
  unsigned short PMR;
  struct
  {
    unsigned short CTMS          : 1;
    unsigned short SCM           : 1;
    unsigned short CTM           : 1;
    unsigned short CKRY          : 1;
    unsigned short PFI           : 1;
    unsigned short BGS           : 1;
    unsigned short ACTMS         : 2;
    unsigned short ACM           : 1;
    unsigned short ACTM          : 1;
    unsigned short ACKRY         : 1;
    unsigned short EPFI          : 1;
    unsigned short X1BY          : 1;
    unsigned short X2BY          : 1;
    unsigned short X32BY         : 1;
  } PMR_bit;
} @ _M(1,8);

/* I2C Control Register */
__no_init volatile __io union
{
  unsigned char I2CCN;
  struct
  {
    unsigned char I2CEN         : 1;
    unsigned char I2CMST        : 1;
    unsigned char I2CMODE       : 1;
    unsigned char I2CEA         : 1;
    unsigned char I2CSTRS       : 1;
    unsigned char I2CACK        : 1;
    unsigned char I2CSTART      : 1;
    unsigned char I2CSTOP       : 1;
  } I2CCN_bit;
} @ _M(1,9);


/* I2C Clock Control Register */
__no_init volatile __io union
{
  unsigned short I2CCK;
  struct
  {
    unsigned short I2CCKL       : 8;
    unsigned short I2CCKH       : 8;
  } I2CCK_bit;
} @ _M(1,0xA);


__no_init volatile __io unsigned char I2CTO @ _M(1,0xB);   /* I2C Timeout Register */


__no_init volatile __io unsigned short I2CSLA @ _M(1,0xC); /* I2C Slave Address Register */


/* Test Mode Register 2 */
__no_init volatile __io union
{
  unsigned short TM2;
  struct
  {
    unsigned short TRIM       : 6;
    unsigned short TSEL       : 2;
    unsigned short XT1        : 2;
    unsigned short XT2        : 2;
  } TM2_bit;
} @ _M(1,0xD);


/* Flash Control Register */
__no_init volatile __io union
{
  unsigned char FCNTL;
  struct
  {
    unsigned char FC0             : 1;
    unsigned char FC1             : 1;
    unsigned char FC2             : 1;
    unsigned char                 : 4;
    unsigned char FBUSY           : 1;
  } FCNTL_bit;
} @ _M(1,0xE);


__no_init volatile __io unsigned char FDATA @ _M(1,0xF);  /* Flash Data Register */


__no_init volatile __io unsigned short ICDT0 @ _M(1,0x18);   /* In-circuit Debug Temp 0 Register */


__no_init volatile __io unsigned short ICDT1 @ _M(1,0x19);   /* In-circuit Debug Temp 1 Register */


/* In-circuit Debug Control Register */
__no_init volatile __io union
{
  unsigned char ICDC;
  struct
  {
    unsigned char CMD0           : 1;
    unsigned char CMD1           : 1;
    unsigned char CMD2           : 1;
    unsigned char CMD3           : 1;
    unsigned char                : 1;
    unsigned char REGE           : 1;
    unsigned char TE             : 1;
    unsigned char DME            : 1;
  } ICDC_bit;
} @ _M(1,0x1A);


/* In-circuit Debug Flag Register */
__no_init volatile __io union
{
  unsigned char ICDF;
  struct
  {
    unsigned char TXC            : 1;
    unsigned char SPE            : 1;
    unsigned char PSS0           : 1;
  } ICDF_bit;
} @ _M(1,0x1B);


__no_init volatile __io unsigned char ICDB @ _M(1,0x1C);   /* In-circuit Debug Buffer Register */


__no_init volatile __io unsigned char ICDA @ _M(1,0x1D);   /* In-circuit Debug Address Register */


__no_init volatile __io unsigned char ICDD @ _M(1,0x1E);   /* In-circuit Debug Data Register */


/* Test Mode Register */
__no_init volatile __io union
{
  unsigned short TM;
  struct
  {
    unsigned short TME            : 1;
    unsigned short                : 1;
    unsigned short CKT            : 1;
    unsigned short SRT            : 1;
    unsigned short DOFF           : 1;
    unsigned short IDDQ           : 1;
    unsigned short DCW            : 1;
    unsigned short COUT           : 2;
    unsigned short DBPIDLE        : 1;
    unsigned short PLLTRIM        : 1;
    unsigned short BGTRIM         : 1;
    unsigned short RCOUT          : 3;
  } TM_bit;
} @ _M(1,0x1F);


/*-------------------------------*
 *           Module 2            *
 *-------------------------------*/


/* Data Manager Interrupt Control Register */
__no_init volatile __io union
{
  unsigned short DMINT;
  struct
  {
    unsigned short PYTXIF         : 1;
    unsigned short DMTXIF         : 1;
    unsigned short PYRXIF         : 1;
    unsigned short DMRXIF         : 1;
    unsigned short DESIF          : 1;
    unsigned short PCSIF          : 1;
    unsigned short FDIF           : 1;
    unsigned short RXOVRIF        : 1;
    unsigned short PYTXIE         : 1;
    unsigned short DMTXIE         : 1;
    unsigned short PYRXIE         : 1;
    unsigned short DMRXIE         : 1;
    unsigned short DESIE          : 1;
    unsigned short PCSIE          : 1;
    unsigned short FDIE           : 1;
    unsigned short RXOVRIE        : 1;
  } DMINT_bit;
} @ _M(2,0);


/* DES Control Register */
__no_init volatile __io union
{
  unsigned char DESCN;
  struct
  {
    unsigned char START          : 1;
    unsigned char MODE           : 1;
    unsigned char DOP            : 2;
    unsigned char DONE           : 1;
    unsigned char                : 3;
  } DESCN_bit;
} @ _M(2,1);


__no_init volatile __io unsigned short DESAD @ _M(2,2); /* DES Address Register */


__no_init volatile __io unsigned short DESCNT @ _M(2,3); /* DES Block Count Register */


__no_init volatile __io unsigned short DESKEY @ _M(2,4); /* DES Key Register */


__no_init volatile __io unsigned short CRC32 @ _M(2,5); /* DES CRC32 Register */


/* Serial Port Control Register */
__no_init volatile __io union
{
  unsigned char SCON;
  struct
  {
    unsigned char RI              : 1;
    unsigned char TI              : 1;
    unsigned char RB8             : 1;
    unsigned char TB8             : 1;
    unsigned char REN             : 1;
    unsigned char SM2             : 1;
    unsigned char SM1             : 1;
    unsigned char SM0             : 1;    
  } SCON_bit;
} @ _M(2,6);


__no_init volatile __io unsigned char SBUF @ _M(2,7);   /* Serial Port Data Buffer Register */


/* Serial Port FIFO Control Register */
__no_init volatile __io union
{
  unsigned char FCON;
  struct
  {
    unsigned char FE              : 1;
    unsigned char OEIE            : 1;
    unsigned char RXFT            : 2;
    unsigned char TXFT            : 2;
    unsigned char FRF             : 1;
    unsigned char FTF             : 1;
  } FCON_bit;
} @ _M(2,8);


/* Serial Port FIFO Status Register */
__no_init volatile __io union
{
  unsigned char FSTAT;
  struct
  {
    unsigned char RXFE            : 1;
    unsigned char RXFAF           : 1;
    unsigned char RXFF            : 1;
    unsigned char TXFE            : 1;
    unsigned char TXFAE           : 1;
    unsigned char TXFF            : 1;
    unsigned char OE              : 1;
  } FSTAT_bit;
} @ _M(2,9);


/* Serial Port Mode Register */
__no_init volatile __io union
{
  unsigned char SMD;
  struct
  {
    unsigned char FEDE            : 1;
    unsigned char SMOD            : 1;
    unsigned char ESI             : 1;
  } SMD_bit;
} @ _M(2,0xA);


__no_init volatile __io unsigned short PR @ _M(2,0xB); /* Phase Register 0 */


/* Buffer Manager Control Register */
__no_init volatile __io union
{
  unsigned short BMCN;
  struct
  {
    unsigned short P0BR           : 4;
    unsigned short P0WBM          : 1;
    unsigned short P1BR           : 4;
    unsigned short P1WBM          : 1;
    unsigned short P2BR           : 4;
    unsigned short P2WBM          : 1;
  } BMCN_bit;
} @ _M(2,0xC);

/* Data Manager Interrupt Control Register 2*/
__no_init volatile __io union
{
  unsigned short DMINT2;
  struct
  {
    unsigned short ACKDIF         : 1;
    unsigned short                : 7;
    unsigned short ACKDIE         : 1;
  } DMINT2_bit;
} @ _M(2,0xD);


__no_init volatile __io unsigned short DMOHAD @ _M(2,0xE); /* Data Manager Output Header Address Register */

__no_init volatile __io unsigned short DMODAD @ _M(2,0x10); /* Data Manager Output Data Address Register */

__no_init volatile __io unsigned char DMODLN @ _M(2,0x11);   /* Data Manager Output Length Register */

__no_init volatile __io unsigned short DMIHAD @ _M(2,0x12); /* Data Manager Input Header Address Register */

__no_init volatile __io unsigned short DMIDAD @ _M(2,0x13); /* Data Manager Input Data Address Register */

__no_init volatile __io unsigned short DMDAD @ _M(2,0x14); /* Data Manager Device Address Register */

__no_init volatile __io unsigned short DMLAD @ _M(2,0x15); /* Data Manager Local Address Register */

__no_init volatile __io unsigned char DMMUL @ _M(2,0x16);   /* Data Manager Multicast Mask Register */

/* Data Manager Control Register */
__no_init volatile __io union
{
  unsigned char DMCN;
  struct
  {
    unsigned char PROM            : 1;
    unsigned char OSTART          : 1;
    unsigned char ISTART          : 1;
    unsigned char CRCRXF          : 1;
    unsigned char PKTREJ          : 1;
    unsigned char AISTART         : 1;
  } DMCN_bit;
} @ _M(2,0x17);

/* AFE Interface Control Register */
__no_init volatile __io union
{
  unsigned short AFEIC;
  struct
  {
    unsigned short AFERXEN        : 1;
    unsigned short AFETXEN        : 1;
    unsigned short AFEPIEN        : 1;
    unsigned short AFEMD          : 1;
    unsigned short RXLB           : 1;
    unsigned short SWRT           : 1;
    unsigned short RXENPL         : 1;
    unsigned short TXENPL         : 1;
    unsigned short RXCLKINV       : 1;
    unsigned short TXCLKINV       : 1;
    unsigned short ADCFMT         : 1;
    unsigned short DACFMT         : 1;
    unsigned short RXGAIN         : 2;
    unsigned short TXGAIN         : 2;
  } AFEIC_bit;
} @ _M(2,0x18);

/* AFE Receive Control Register */
__no_init volatile __io union
{
  unsigned short AFERXC;
  struct
  {
    unsigned short ADCDL          : 2;
    unsigned short                : 1;
    unsigned short ADCDP          : 3;
    unsigned short RXMD           : 2;
    unsigned short ADCRES         : 8;
  } AFERXC_bit;
} @ _M(2,0x19);


/* AFE Transmit Control Register 0 */
__no_init volatile __io union
{
  unsigned short AFETXC0;
  struct
  {
    unsigned short DACDL          : 2;
    unsigned short AFE_RESETN     : 1;
    unsigned short DACDP          : 3;
    unsigned short ENDLY          : 2;
    unsigned short DACRES         : 8;
  } AFETXC0_bit;
} @ _M(2,0x1A);

__no_init volatile __io unsigned short AFETXC1 @ _M(2,0x1B); /* AFE Transmit Control Register 1 */


/* AFE Clock Control Register */
__no_init volatile __io union
{
  unsigned char AFECKCN;
  struct
  {
    unsigned char AFECD          : 2;
    unsigned char AXDONE         : 1;
    unsigned char PHYCK          : 1;
    unsigned char PHYCD          : 2;
    unsigned char AFEXKILL       : 1;
  } AFECKCN_bit;
} @ _M(2,0x1C);

/*-------------------------------*
 *           Module 3            *
 *-------------------------------*/


__no_init volatile __io unsigned short TB0R @ _M(3,0); /* Timer 0 Capture/Reload Register */


__no_init volatile __io unsigned short TB0C @ _M(3,1); /* Timer 0 Compare Register */


__no_init volatile __io unsigned short TB1R @ _M(3,2); /* Timer 0 Capture/Reload Register */


__no_init volatile __io unsigned short TB1C @ _M(3,3); /* Timer 0 Compare Register */


__no_init volatile __io unsigned short TB2R @ _M(3,4); /* Timer 0 Capture/Reload Register */


__no_init volatile __io unsigned short TB2C @ _M(3,5); /* Timer 0 Compare Register */


__no_init volatile __io unsigned short TB3R @ _M(3,6); /* Timer 0 Capture/Reload Register */


__no_init volatile __io unsigned short TB3C @ _M(3,7); /* Timer 0 Compare Register */


/* Timer 0 Control Register */
__no_init volatile __io union
{
  unsigned short TB0CN;
  struct
  {
    unsigned short CPRLB          : 1;
    unsigned short ETB            : 1;
    unsigned short TRB            : 1;
    unsigned short EXENB          : 1;
    unsigned short DCEN           : 1;
    unsigned short TBOE           : 1;
    unsigned short EXFB           : 1;
    unsigned short TFB            : 1;
    unsigned short TBPS           : 3;
    unsigned short TBCR           : 1;
    unsigned short TBCS           : 1;
    unsigned short                : 2;
    unsigned short CTB            : 1;
  } TB0CN_bit;
} @ _M(3,8);

/* Timer 0 Value Register */
__no_init volatile __io unsigned short TB0V @ _M(3,9); 


/* Timer 1 Control Register */
__no_init volatile __io union
{
  unsigned short TB1CN;
  struct
  {
    unsigned short CPRLB          : 1;
    unsigned short ETB            : 1;
    unsigned short TRB            : 1;
    unsigned short EXENB          : 1;
    unsigned short DCEN           : 1;
    unsigned short TBOE           : 1;
    unsigned short EXFB           : 1;
    unsigned short TFB            : 1;
    unsigned short TBPS           : 3;
    unsigned short TBCR           : 1;
    unsigned short TBCS           : 1;
    unsigned short                : 2;
    unsigned short CTB            : 1;
  } TB1CN_bit;
} @ _M(3,0xA);

/* Timer 1 Value Register */
__no_init volatile __io unsigned short TB1V @ _M(3,0xB); 


/* Timer 2 Control Register */
__no_init volatile __io union
{
  unsigned short TB2CN;
  struct
  {
    unsigned short CPRLB          : 1;
    unsigned short ETB            : 1;
    unsigned short TRB            : 1;
    unsigned short EXENB          : 1;
    unsigned short DCEN           : 1;
    unsigned short TBOE           : 1;
    unsigned short EXFB           : 1;
    unsigned short TFB            : 1;
    unsigned short TBPS           : 3;
    unsigned short TBCR           : 1;
    unsigned short TBCS           : 1;
    unsigned short                : 2;
    unsigned short CTB            : 1;
  } TB2CN_bit;
} @ _M(3,0xC);

/* Timer 2 Value Register */
__no_init volatile __io unsigned short TB2V @ _M(3,0xD); 


/* Timer 3 Control Register */
__no_init volatile __io union
{
  unsigned short TB3CN;
  struct
  {
    unsigned short CPRLB          : 1;
    unsigned short ETB            : 1;
    unsigned short TRB            : 1;
    unsigned short EXENB          : 1;
    unsigned short DCEN           : 1;
    unsigned short TBOE           : 1;
    unsigned short EXFB           : 1;
    unsigned short TFB            : 1;
    unsigned short TBPS           : 3;
    unsigned short TBCR           : 1;
    unsigned short TBCS           : 1;
    unsigned short                : 2;
    unsigned short CTB            : 1;
  } TB3CN_bit;
} @ _M(3,0xE);

/* Timer 3 Value Register */
__no_init volatile __io unsigned short TB3V @ _M(3,0xF); 


/*-------------------------------*
 *           Module 4            *
 *-------------------------------*/


__no_init volatile __io unsigned short TB4R @ _M(4,0); /* Timer 4 Capture/Reload Register */

__no_init volatile __io unsigned short TB4C @ _M(4,1); /* Timer 4 Compare Register */

__no_init volatile __io unsigned short TB5R @ _M(4,2); /* Timer 5 Capture/Reload Register */

__no_init volatile __io unsigned short TB5C @ _M(4,3); /* Timer 5 Compare Register */

__no_init volatile __io unsigned short TB6R @ _M(4,4); /* Timer 6 Capture/Reload Register */

__no_init volatile __io unsigned short TB6C @ _M(4,5); /* Timer 6 Compare Register */


/* Timer 4 Control Register */
__no_init volatile __io union
{
  unsigned short TB4CN;
  struct
  {
    unsigned short CPRLB          : 1;
    unsigned short ETB            : 1;
    unsigned short TRB            : 1;
    unsigned short EXENB          : 1;
    unsigned short DCEN           : 1;
    unsigned short TBOE           : 1;
    unsigned short EXFB           : 1;
    unsigned short TFB            : 1;
    unsigned short TBPS           : 3;
    unsigned short TBCR           : 1;
    unsigned short TBCS           : 1;
    unsigned short                : 2;
    unsigned short CTB            : 1;
  } TB4CN_bit;
} @ _M(4,8);

/* Timer 4 Value Register */
__no_init volatile __io unsigned short TB4V @ _M(4,9); 

/* Timer 5 Control Register */
__no_init volatile __io union
{
  unsigned short TB5CN;
  struct
  {
    unsigned short CPRLB          : 1;
    unsigned short ETB            : 1;
    unsigned short TRB            : 1;
    unsigned short EXENB          : 1;
    unsigned short DCEN           : 1;
    unsigned short TBOE           : 1;
    unsigned short EXFB           : 1;
    unsigned short TFB            : 1;
    unsigned short TBPS           : 3;
    unsigned short TBCR           : 1;
    unsigned short TBCS           : 1;
    unsigned short                : 2;
    unsigned short CTB            : 1;
  } TB5CN_bit;
} @ _M(4, 0xA);

/* Timer 5 Value Register */
__no_init volatile __io unsigned short TB5V @ _M(4, 0xB); 

/* Timer 6 Control Register */
__no_init volatile __io union
{
  unsigned short TB6CN;
  struct
  {
    unsigned short CPRLB          : 1;
    unsigned short ETB            : 1;
    unsigned short TRB            : 1;
    unsigned short EXENB          : 1;
    unsigned short DCEN           : 1;
    unsigned short TBOE           : 1;
    unsigned short EXFB           : 1;
    unsigned short TFB            : 1;
    unsigned short TBPS           : 3;
    unsigned short TBCR           : 1;
    unsigned short TBCS           : 1;
    unsigned short                : 2;
    unsigned short CTB            : 1;
  } TB6CN_bit;
} @ _M(4, 0xC);


__no_init volatile __io unsigned short TB6V @ _M(4, 0xD); /* Timer 6 Value Register */

/*-------------------------------*
 *           Module 5            *
 *-------------------------------*/


__no_init volatile __io unsigned short PHYMPTR @ _M(5,0);   /* Phy Memory Pointer Register */


__no_init volatile __io unsigned short PHYMDATA @ _M(5,1);   /* PHY Memory Data Register */


__no_init volatile __io unsigned short PCTHR @ _M(5,2);   /* Channel Threshold Register */


/* PHY Control Register */
__no_init volatile __io union
{
  unsigned short PCR;
  struct
  {
    unsigned short TXRETRAN       : 1;
    unsigned short ACKSTART       : 1;
    unsigned short PHYEN          : 1;
    unsigned short PHYMOD         : 1;
    unsigned short JDEN           : 1;
    unsigned short JCEN           : 1;
    unsigned short HPFEN          : 1;
    unsigned short TXROBOEN       : 1;
    unsigned short DAGCEN         : 1;
    unsigned short DAGCFRZ        : 1;
    unsigned short RXMD           : 2;
    unsigned short RXRST          : 1;
    unsigned short TXRST          : 1;
    unsigned short CRCEN          : 1;
    unsigned short PHYCNF         : 1;
  } PCR_bit;
} @ _M(5,3);


/* PHY Status Register */
__no_init volatile __io union
{
  unsigned short PSR;
  struct
  {
    unsigned short PYCS          : 1;
    unsigned short P1F           : 1;
    unsigned short P2F           : 1;
    unsigned short RXFMD         : 1;
    unsigned short TXBY          : 1;
    unsigned short JAMF          : 1;
    unsigned short FRMRX         : 1;
    unsigned short CRCOK         : 1;
    unsigned short ATEN          : 1;
    unsigned short FECDATA       : 1;
  } PSR_bit;
} @ _M(5,4);


/* PHY Control Register 2 */
__no_init volatile __io union
{
  unsigned short PCR2;
  struct
  {
    unsigned short EXPACK         : 1;
    unsigned short MACKRXEN       : 1;
    unsigned short                : 1;
    unsigned short PREEMPEN       : 1;
    unsigned short DBPHYHALT      : 1;
  } PCR2_bit;
} @ _M(5,5);

__no_init volatile __io unsigned short RMSCREG @ _M(5,6);  /* RMS Communication Register */


__no_init volatile __io unsigned short AGC1 @ _M(5,7); /* AGC Control Register 1 - AGC Forget Factor */


__no_init volatile __io unsigned short AGC2 @ _M(5,8); /* AGC Control Register 2 - AGC Desired Energy */


__no_init volatile __io unsigned short AGC3 @ _M(5,9); /* AGC Control Register 3 - AGC Window Length */


/* AGC Control Register 4 - AGC Gain Shift and Window Shift */
__no_init volatile __io union
{
  unsigned short AGC4;
  struct
  {
    unsigned short AWS           : 4;
    unsigned short AGS           : 4;
    unsigned short AAFO          : 1;
    unsigned short RMSMD         : 1;
  } AGC4_bit;
} @ _M(5,0xA);


/* Demodulator Control Register */
__no_init volatile __io union
{
  unsigned short DEM;
  struct
  {
    unsigned short SYMOF          : 8;
    unsigned short SOFT           : 4;
  } DEM_bit;
} @ _M(5,0xB);


/* Synchronizer Control Register 1 */
__no_init volatile __io union
{
  unsigned short SYNC1;
  struct
  {
    unsigned short SYNCMD         : 1;
    unsigned short NBSBS          : 5;
    unsigned short                : 2;
    unsigned short OFS            : 8;
  } SYNC1_bit;
} @ _M(5,0xC);


/* Synchronizer Control Register 2 */
__no_init volatile __io union
{
  unsigned short SYNC2;
  struct
  {
    unsigned short P2TW            : 8;
    unsigned short P1TW            : 8;
  } SYNC2_bit;
} @ _M(5,0xD);

/* Synchronizer Control Register 3 - SYNC Threshold 1 */
__no_init volatile __io unsigned short SYNC3 @ _M(5,0xE); 

/* Synchronizer Control Register 4 - SYNC Threshold 2 */
__no_init volatile __io unsigned short SYNC4 @ _M(5,0xF); 


/* Interleaver Control Register */
__no_init volatile __io union
{
  unsigned short INTRL;
  struct
  {
    unsigned short NCOL           : 7;
    unsigned short IOFS           : 9;
  } INTRL_bit;
} @ _M(5,0x10);


/* FEC Control Register 1 */
__no_init volatile __io union
{
  unsigned short FEC1;
  struct
  {
    unsigned short NMPAD          : 5;
    unsigned short RMPAD          : 5;
    unsigned short RSPAR          : 1;
  } FEC1_bit;
} @ _M(5,0x11);


/* FEC Control Register 2 */
__no_init volatile __io union
{
  unsigned short FEC2;
  struct
  {
    unsigned short RSNSZ          : 8;
    unsigned short RSRSZ          : 8;
  } FEC2_bit;
} @ _M(5,0x12);


__no_init volatile __io unsigned short DCB @ _M(5,0x13); /* DC Blocker Register */


/* Transmit Preamble Control Register */
__no_init volatile __io union
{
  unsigned short TXPC;
  struct
  {
    unsigned short PSYM           : 4;
    unsigned short F1F2P          : 4;
    unsigned short PACK           : 4;
    unsigned short F1F2ACK        : 4;
  } TXPC_bit;
} @ _M(5,0x14);


__no_init volatile __io unsigned short PCSNR @ _M(5,0x16); /* PC Signal to Noise Ratio Register */


__no_init volatile __io unsigned short MOD1 @ _M(5,0x17); /* Modulator Control Register 1 */

/* Modulator Control Register 2 */
__no_init volatile __io union
{
  unsigned short MOD2;
  struct
  {
    unsigned short SFREQ         : 7;
    unsigned short NFREQ         : 7;
  } MOD2_bit;
} @ _M(5,0x18);

__no_init volatile __io unsigned short MOD3 @ _M(5,0x19); /* Modulator Control Register 3 */


__no_init volatile __io unsigned short JAM1 @ _M(5,0x1A); /* Jammer Control Register 1 */


__no_init volatile __io unsigned short JAM2 @ _M(5,0x1B); /* Jammer Control Register 2 */


__no_init volatile __io unsigned short JAM3 @ _M(5,0x1C); /* Jammer Control Register 3 */


/* Jammer Control Register 4 */
__no_init volatile __io union
{
  unsigned short JAM4;
  struct
  {
    unsigned short JDETP          : 8;
    unsigned short JDETN          : 8;
  } JAM4_bit;
} @ _M(5,0x1D);


__no_init volatile __io unsigned short JAM5 @ _M(5,0x1E); /* Jammer Control Register 5 */


__no_init volatile __io unsigned short JAM6 @ _M(5,0x1F); /* Jammer Control Register 6 */



/*-------------------------------*
 *           Module 8            *
 *-------------------------------*/

/* Clock Control register */
__no_init volatile __io union
{
  unsigned char CKCN;
  struct
  {
    unsigned char CD0            : 1;
    unsigned char CD1            : 1;
    unsigned char PMME           : 1;
    unsigned char SWB            : 1;
    unsigned char STOP           : 1;
    unsigned char RGMD           : 1;
    unsigned char RGSL           : 1;
    unsigned char IDLE           : 1;
  } CKCN_bit;
} @ _M(8,0x0E);


/* Watchdog Control register */
__no_init volatile __io union
{
  unsigned char WDCN;
  struct
  {
    unsigned char RWT            : 1;
    unsigned char EWT            : 1;
    unsigned char WTRF           : 1;
    unsigned char WDIF           : 1;
    unsigned char WD0            : 1;
    unsigned char WD1            : 1;
    unsigned char EWDI           : 1;
    unsigned char POR            : 1;
  } WDCN_bit;
} @ _M(8,0x0F);




#pragma language=default
#endif  /* __IAR_SYSTEMS_ICC__  */
#endif /* __IOMAXQWV17 */

