  // *******************************************************************************
  // *
  // *  Copyright (C) 2007 Dallas/Maxim Semiconductor Corporation. 
  // *  All rights Reserved. Printed in U.S.A.
  // *
  // *  This software is protected by copyright laws of the United States and of 
  // *  foreign countries.  This material may also be protected by patent laws of
  // *  the United States and of foreign countries. This software is furnished 
  // *  under a license agreement and/or a nondisclosure agreement and may only 
  // *  be used or copied in accordance with the terms of those agreements.  The 
  // *  mere transfer of this software does not imply any licenses of trade 
  // *  secrets, proprietary technology, copyrights, patents, trademarks, 
  // *  maskwork rights, or any other form of intellectual property whatsoever. 
  // *  Dallas/Maxim Semiconductor retains all ownership rights.
  // *
  // *
  // *     Description: MAX2990
  // *        Filename: uart.c
  // *          Author: Konrad Scheuer
  // *        Compiler: IAR
  // *         Version: 2.20I
  // *         Created: 2009_11_27
  // *
  // *         Purpose: Basic UART routines to allow controls and printf through Hyperterminal
  // *												
  // *******************************************************************************


#include <stdio.h>
#include "inc/iomaxqwv17_B1.h"
#include "iomaxq.h"
#include "uart.h"

void UART_init(UINT16 baud)
{
  UART_HW_CTRL;   // Configure P2.6 and P2.7 pins for UART hardware control
  CLEAR_CTS;      // Ready to accept data from UART

  SCON = 0x50;   // Receiver enabled, SM1 = 1
                 // Asynchronous mode 1: 1 start + 8 data + 1 stop = 10 bits

  FCON = 0xCD;   // Enable FIFO, RX FIFO >75% full, TX FIFO empty, flush RX/TX FIFOs
  SMD = 0x4;     // Enable serial port interrupts, SMOD = 0 (CLK/64), FEDE = 0
  
  PR = baud;     // Set phase register 
                 // P = baud_rate * ((2^23) / (2^(SMOD*2))) / CLK 
                 // P = 115200 * ((2^23) / (2^(0*2))) / (33.999938 * 10^6) = 28423

  IMR |= 0x4;    // Enable interrupts for module 2 (UART)
}


int putchar(int outchar)
{
  while(FSTAT_bit.TXFF);   // Wait if FIFO buffer is full
  SBUF = outchar;          // Send the Byte through UART
  return outchar;          // return it back
}


int getchar (void)
{
  while(FSTAT_bit.RXFE == 1)  {}  // Wait for received character (Deadly Embrace!!!)  
  SCON_bit.RI = 0;                // Clear Receive Interrupt Flag
  return SBUF;                    // Return the Received Data    
}


int get_number_from_keyboard (void)
{
  int input=0;
  int number=0;
  
  while (input != 0x0d)                        // loop untils ENTER = 0x0d is received
  {       
    input = getchar();                         // wait for a character
    if ( (input > 0x2f) && (input < 0x3a) )    // only if a valid number (0-9 was received)
    {
      putchar (input);                         // print it out
      number = number * 10 + (input - 0x30);   // calculate the number from the character
    }    
  }   
  return number;                               // return the number
}

int get_digit_from_keyboard (int min, int max)
{
  int input=0;
  
  while ( (input < (0x30+min)) || (input > (0x30+max)) ) // ENTER = 0x0d, 
  {       
    input = getchar();
  }   
  printf("%c\n\r",input);
  return input-0x30;
}

void get_enter_from_keyboard(void)
{    
  int input=0;
  
    // only wait for "ENTER"
    while (input != 0x0d) // ENTER = 0x0d, 
    {input = getchar();}
}


void clear_screen (void)
{
    putchar (0x0c);
}


void keyboard_test (void)
{
  int input=0;
  
  while (input != 0x0d) // ENTER = 0x0d, 
  {       
    input = getchar();
    putchar (input);
  }   
}



// printf German special characters

// 0x84="" 
// 0x94="" 
// 0x81="" 

// 0x8e="" 
// 0x99=""
// 0x9a="" 
